@@ -5,10 +5,14 @@
     license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
 
-from csb43.utils import check_strict, raiseCsb43Exception
-import csb43.utils.messages as msg
+from __future__ import unicode_literals
+from __future__ import absolute_import
+
+from ..utils import check_strict, raiseCsb43Exception, m3_is_string
+from ..utils import messages as msg
 #from csb43.i18n import tr as _
 
+
 class Item(object):
     '''
     Complementary item / (es) Concepto adicional (registro 23)
@@ -16,7 +20,8 @@ class Item(object):
     - Create an :class:`Item` object from a `CSB43` string record::
 
         >>> from csb43.csb43 import Item
-        >>> record = '2301primer concepto adicional             segundo concepto adicional            '
+        >>> record = '2301primer concepto adicional             segundo \
+concepto adicional            '
         >>> i = Item(record)
         >>> i.item1
         'primer concepto adicional'
@@ -32,7 +37,8 @@ class Item(object):
         >>> i.item2 = 'segundo concepto adicional'
         >>> i.recordCode = 1
         >>> str(i)
-        '2301primer concepto adicional             segundo concepto adicional            '
+        '2301primer concepto adicional             segundo concepto \
+adicional            '
     '''
 
     def __init__(self, record=None, strict=True):
@@ -61,7 +67,7 @@ class Item(object):
             self._set_item_2(record[42:80], self.__strict)
 
     def is_valid(self, record):
-        return isinstance(record, basestring) and\
+        return m3_is_string(record) and\
             (len(record) == 80) and (record[0:2] == '23')
 
     def _get_record_code(self):
@@ -99,20 +105,22 @@ class Item(object):
     def __str__(self):
         ':rtype: representation of this object as a `CSB43` record'
         return "23{record_code:0>2}{item1: <38}{item2: <38}".format(
-                record_code = self.__recordCode or '',
-                item1 = self.__item1 or '',
-                item2 = self.__item2 or ''
-            )
+            record_code=self.__recordCode or '',
+            item1=self.__item1 or '',
+            item2=self.__item2 or ''
+        )
 
     def __iter__(self):
         return iter([str(self)])
 
     def as_dict(self):
         '''
-        :rtype: a representation of this object as a :class:`dict`. The keys will be localised
+        :rtype: a representation of this object as a :class:`dict`. The keys \
+        will be localised
 
-            >>> i.as_dict()
-            {u'concepto1': 'primer concepto adicional', u'concepto2': 'segundo concepto adicional', u'codigo_de_registro': 1}
+        >>> i.as_dict()
+        {u'concepto1': 'primer concepto adicional', u'concepto2': 'segundo \
+        concepto adicional', u'codigo_de_registro': 1}
 
         '''
         return {
@@ -140,10 +148,12 @@ Code can be assigned as a number or as a string::
     ... except Exception, e:
     ...     print e
     ...
-    mal formato: el contenido '10' no concuerda con el formato esperado r'^0[12345]$' para este campo
+    mal formato: el contenido '10' no concuerda con el formato \
+esperado r'^0[12345]$' para este campo
 
 """)
     item1 = property(_get_item_1, _set_external_item_1, None,
                      "first additional item / (es) primer concepto adicional")
     item2 = property(_get_item_2, _set_external_item_2, None,
-                     "second additional item / (es) segundo concepto adicional")
+                     "second additional item / (es) segundo concepto "
+                     "adicional")
