@@ -5,12 +5,22 @@
     license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
 
-from csb43.utils import DECIMAL, raiseCsb43Exception, check_strict
-import csb43.utils.messages as msg
-from csb43.i18n import tr as _
-from item import Item
-from record import Record
-from exchange import Exchange
+#from __future__ import print_function
+from __future__ import unicode_literals
+from __future__ import absolute_import
+
+
+from ..utils import (DECIMAL,
+                     raiseCsb43Exception,
+                     check_strict,
+                     IS_PY3,
+                     m3_long,
+                     m3_is_string)
+from ..utils import messages as msg
+from ..i18n import tr as _
+from .item import Item
+from .record import Record
+from .exchange import Exchange
 
 
 class Transaction(Record):
@@ -27,13 +37,17 @@ class Transaction(Record):
         >>> t = Transaction()
         >>> t.amount = 123.45
         >>> str(t)
-        '22    0000000000000000000002000000000123450000000000000000000000                '
+        '22    000000000000000000000200000000012345000000000000000000000\
+0                '
     '''
 
     MAX_ITEMS = 5
 
-    def __init__(self, record=None, strict=True, decimal=DECIMAL,
-                yearFirst=True):
+    def __init__(self,
+                 record=None,
+                 strict=True,
+                 decimal=DECIMAL,
+                 yearFirst=True):
         '''
         :param record: csb record
         :type record: :class:`basestring` or `None`
@@ -41,10 +55,12 @@ class Transaction(Record):
         :param strict: treat warnings as exceptions when `True`
         :type strict: :class:`bool`
 
-        :param decimal: number of digits to be considered as the decimal part in money
+        :param decimal: number of digits to be considered as the decimal part \
+        in money
         :type decimal: :class:`int`
 
-        :param yearFirst: switch between YYMMD [`True`] and DDMMYY [`False`] date formats
+        :param yearFirst: switch between YYMMD [`True`] and DDMMYY [`False`] \
+        date formats
         :type yearFirst: :class:`bool`
 
         :raises: :class:`csb43.utils.Csb43Exception`
@@ -102,7 +118,7 @@ class Transaction(Record):
     def _set_exchange(self, value):
         self.__exchange = value
 
-    def add_exchange(self, record, update = False):
+    def add_exchange(self, record, update=False):
         '''
         Add a new additional exchange record to the transaction
 
@@ -120,7 +136,8 @@ class Transaction(Record):
             >>> record = '{: <80}'.format('240197800000000012345')
             >>> t.add_exchange(record)
             >>> str(t.exchange)
-            '240197800000000012345                                                           '
+            '24019780000000001234\
+5                                                           '
 
         Add an exchange object from a :class:`Exchange`::
 
@@ -133,13 +150,15 @@ class Transaction(Record):
             '240197800000000012345                                                           '
 
         '''
-        if isinstance(record, basestring):
+        if m3_is_string(record):
             exchange = Exchange(record, decimal=self._decimal,
                                 strict=self.__strict)
         elif isinstance(record, Exchange):
             exchange = record
         else:
-            raiseCsb43Exception(msg.INCOMPATIBLE_OBJECT(record, "Exchange", "basestring"), True)
+            raiseCsb43Exception(msg.INCOMPATIBLE_OBJECT(record,
+                                                        "Exchange",
+                                                        "basestring"), True)
 
         if (self.__exchange is not None) and not update:
             raiseCsb43Exception(_("maximum number of exchange record"
@@ -148,7 +167,7 @@ class Transaction(Record):
 
     @staticmethod
     def is_valid(record):
-        return isinstance(record, basestring) and\
+        return m3_is_string(record) and\
             (len(record) == 80) and (record[0:2] == '22')
 
     def _get_expense_or_income(self):
@@ -188,7 +207,7 @@ class Transaction(Record):
     def _validate_reference(value, strict):
         n = value.strip(' ')
         try:
-            long(n)
+            m3_long(n)
             control = int(n[-1])
             res = (sum([int(x) * ((i % 8) + 2) for (i, x)
                         in enumerate(reversed(n[:-1]))]) % 11) % 10
@@ -276,7 +295,7 @@ class Transaction(Record):
         self.__commonItem = value
 
     def _set_external_common_item(self, value):
-        if isinstance(value, basestring):
+        if m3_is_string(value):
             self._set_common_item(value)
         else:
             v = int(value)
@@ -292,7 +311,7 @@ class Transaction(Record):
         self.__ownItem = value
 
     def _set_external_own_item(self, value):
-        if isinstance(value, basestring):
+        if m3_is_string(value):
             self._set_own_item(value)
         else:
             v = int(value)
@@ -305,18 +324,22 @@ class Transaction(Record):
         :param record: item record
         :type record: :class:`Item` or :class:`basestring`
 
-        :raises: :class:`csb43.utils.Csb43Exception` when the record is impossible to parse, or if the         maximum number of complementary items has been reached
+        :raises: :class:`csb43.utils.Csb43Exception` when the record is \
+        impossible to parse, or if the maximum number of complementary items \
+        has been reached
         '''
         if len(self.__items) == Transaction.MAX_ITEMS:
             raiseCsb43Exception(_("the maximum number of complementary items"
                                 " for transaction has been reached: %d") %
                                 Transaction.MAX_ITEMS, self.__strict)
-        if isinstance(record, basestring):
+        if m3_is_string(record):
             self.__items.append(Item(record, self.__strict))
         elif isinstance(record, Item):
             self.__items.append(record)
         else:
-            raiseCsb43Exception(msg.INCOMPATIBLE_OBJECT(record, "Item", "basestring"), True)
+            raiseCsb43Exception(msg.INCOMPATIBLE_OBJECT(record,
+                                                        "Item",
+                                                        "basestring"), True)
 
     def _set_external_amount(self, value):
         v = float(value)
@@ -328,52 +351,75 @@ class Transaction(Record):
         if self.__amount is None:
             return None
         return self._format_currency(self.__amount,
-                                    debit=self.__debitOrCredit)
+                                     debit=self.__debitOrCredit)
 
     def __str_main_record(self):
         ':rtype: representation of this object as a `CSB43` record'
-        return "22{padding: <4}{of_code:0>4}{op_date:0>6}{ef_date:0>6}{common_item:0>2}{own_item:0>3}{ex_in:1>1}{amount:0>14}{doc_number:0>10}{ref1:0>12}{ref2: <16}".format(
-                padding = self.__padding or '',
-                of_code = self.__officeCode or '',
-                op_date = self.__operation_date or '',
-                ef_date = self.__effective_date or '',
-                common_item = self.__commonItem or '',
-                own_item = self.__ownItem or '',
-                ex_in = self.__debitOrCredit or '',
-                amount = self.__amount or '',
-                doc_number = self.__documentNumber or '',
-                ref1 = self.__reference1 or '',
-                ref2 = self.__reference2 or ''
-            )
+        return ("22"
+                "{padding: <4}{of_code:0>4}{op_date:0>6}{ef_date:0>6}"
+                "{common_item:0>2}{own_item:0>3}{ex_in:1>1}{amount:0>14}"
+                "{doc_number:0>10}{ref1:0>12}{ref2: <16}".format(
+                    padding=self.__padding or '',
+                    of_code=self.__officeCode or '',
+                    op_date=self.__operation_date or '',
+                    ef_date=self.__effective_date or '',
+                    common_item=self.__commonItem or '',
+                    own_item=self.__ownItem or '',
+                    ex_in=self.__debitOrCredit or '',
+                    amount=self.__amount or '',
+                    doc_number=self.__documentNumber or '',
+                    ref1=self.__reference1 or '',
+                    ref2=self.__reference2 or ''
+                ))
 
     def __iter__(self):
-        ''':rtype: iterator of all the `CSB43` records that this object represents
+        ''':rtype: iterator of all the `CSB43` records that this object
+        represents
 
 >>> [x for x in t]
-['22    0000000000120213000002000000001234560000000000012345678900       something', '2301first item record                                                           ', '2302second item record                                                          ', '240184000000000012300                                                           ']
+['22    000000000012021300000200000000123456000000000001234567890\
+0       something', '2301first item recor\
+d                                                           '\
+, '2302second item recor\
+d                                                          '\
+, '24018400000000001230\
+0                                                           ']
 
         '''
         return _TransactionIter(self, self.__str_main_record())
 
     def __str__(self):
-        r''':rtype: representation of this object as `CSB43` records (using `\\n` as separator)
+        r''':rtype: representation of this object as `CSB43` records
+        (using `\\n` as separator)
 
 >>> str(t)
-'22    0000000000120213000002000000001234560000000000012345678900       something\n2301first item record                                                           \n2302second item record                                                          \n240184000000000012300                                                           '
+'22    000000000012021300000200000000123456000000000001234567890\
+0       something\n2301first item recor\
+d                                                           \n2302\
+second item recor\
+d                                                          \n2401840000000\
+00012300                                                           '
         '''
         return '\n'.join([x for x in self])
 
     def as_dict(self):
         '''
-        :rtype: a representation of this object as a :class:`dict`. The keys will be localised
+        :rtype: a representation of this object as a :class:`dict`. \
+        The keys will be localised
 
-            >>> t.as_dict()
-            {u'cantidad': 123.45, u'primera_referencia': None, u'segunda_referencia': None, u'concepto_propio': None, u'fecha_de_operacion': None, u'numero_del_documento': None, u'codigo_de_sucursal': None, u'concepto_comun': None, u'fecha_valor': None}
+        >>> t.as_dict()
+        {u'cantidad': 123.45, u'primera_referencia': None, \
+         u'segunda_referencia': None, u'concepto_propio': None, \
+         u'fecha_de_operacion': None, u'numero_del_documento': None, \
+         u'codigo_de_sucursal': None, u'concepto_comun': None, \
+         u'fecha_valor': None}
         '''
         d = {
             msg.T_BRANCH_CODE: self.branchCode,
-            msg.T_TRANSACTION_DATE: str(self.transactionDate.date()) if self.transactionDate else None,
-            msg.T_VALUE_DATE: str(self.valueDate.date()) if self.valueDate else None,
+            msg.T_TRANSACTION_DATE: (str(self.transactionDate.date())
+                                     if self.transactionDate else None),
+            msg.T_VALUE_DATE: (str(self.valueDate.date())
+                               if self.valueDate else None),
             msg.T_SHARED_ITEM: self.sharedItem,
             msg.T_OWN_ITEM: self.ownItem,
             msg.T_AMOUNT: self.amount,
@@ -392,13 +438,14 @@ class Transaction(Record):
 
     # **** Properties ****
     optionalItems = property(_get_items, None, None,
-                            """list of optional items / (es) lista de conceptos adicionales
+                             """list of optional items / (es) lista de \
+conceptos adicionales
 
 :rtype: :class:`list` of :class:`Item` attached to this transaction
 """)
     padding = property(_get_padding, _set_padding, None, "padding")
     branchCode = property(_get_office_code, _set_office_code, None,
-                        """branch code / (es) código de sucursal u oficina
+                          """branch code / (es) código de sucursal u oficina
 
 :rtype: :class:`str`
 
@@ -408,8 +455,8 @@ class Transaction(Record):
 
 """)
     transactionDate = property(_get_external_operation_date,
-                            _set_external_operation_date, None,
-                            """transaction date / (es) fecha de la operación
+                               _set_external_operation_date, None,
+                               """transaction date / (es) fecha de la operación
 
 :rtype: :class:`datetime.datetime`
 
@@ -421,8 +468,8 @@ Setting a date::
 
 """)
     valueDate = property(_get_external_effective_date,
-                        _set_external_effective_date, None,
-                        """value date / (es) fecha valor
+                         _set_external_effective_date, None,
+                         """value date / (es) fecha valor
 
 :rtype: :class:`datetime.datetime`
 
@@ -434,7 +481,7 @@ Setting a date::
 
 """)
     sharedItem = property(_get_common_item, _set_external_common_item, None,
-                        """inter-bank shared item / (es) concepto común
+                          """inter-bank shared item / (es) concepto común
 
 :rtype: :class:`str`
 
@@ -450,7 +497,8 @@ Setting a date::
 
 """)
     ownItem = property(_get_own_item, _set_external_own_item, None,
-                    """own item (given by each bank to its transactions) / (es) concepto propio del banco
+                       """own item (given by each bank to its transactions) / \
+(es) concepto propio del banco
 
 :rtype: :class:`str`
 
@@ -463,12 +511,13 @@ Setting a date::
 
 """)
     amount = property(_get_external_amount, _set_external_amount, None,
-                    """amount of the transaction / (es) cantidad implicada en el movimiento
+                      """amount of the transaction / (es) cantidad implicada \
+en el movimiento
 
 :rtype: :class:`float`
 
-Quantities can be assigned as numbers or strings, and they will be truncated to adjust the
-decimal format set for the object::
+Quantities can be assigned as numbers or strings, and they will be truncated to
+adjust the decimal format set for the object::
 
     >>> t.amount = 123
     >>> t.amount
@@ -484,8 +533,9 @@ decimal format set for the object::
     1.23
 
 """)
-    documentNumber = property(_get_document_number, _set_external_document_number, None,
-                            """document number / (es) número del documento
+    documentNumber = property(_get_document_number,
+                              _set_external_document_number, None,
+                              """document number / (es) número del documento
 
 :rtype: :class:`int`
 
@@ -495,7 +545,8 @@ decimal format set for the object::
 
                             """)
     reference1 = property(_get_reference_1, _set_reference_1, None,
-                        """first reference (checksummed) / (es) primera referencia (verificada)
+                          """first reference (checksummed) / (es) primera \
+referencia (verificada)
 
 :rtype: :class:`str`
 
@@ -511,7 +562,8 @@ Validación fallida para el campo de referencia '012345678901'
 
                         """)
     reference2 = property(_get_reference_2, _set_reference_2, None,
-                        """second reference (not checksummed) / (es) segunda referencia (no verificada)
+                          """second reference (not checksummed) / (es) \
+segunda referencia (no verificada)
 
 :rtype: :class:`str`
 
@@ -538,6 +590,9 @@ class _TransactionIter(object):
 
         self.__iter = iter(self.__output)
 
-    def next(self):
-        return str(self.__iter.next())
-
+    if IS_PY3:
+        def __next__(self):
+            return str(next(self.__iter))
+    else:
+        def next(self):
+            return str(self.__iter.next())
