@@ -11,6 +11,7 @@ Homebank CSV format
 
     - (http://homebank.free.fr/help/06csvformat.html)
 '''
+from __future__ import absolute_import
 
-from transaction import Transaction
-from converter import convertFromCsb, PAYMODES
\ No newline at end of file
+from .transaction import Transaction
+from .converter import convertFromCsb, PAYMODES
