@@ -1,9 +1,10 @@
 '''
 @license: GNU Lesser General Public License v3.0 (see LICENSE)
 '''
+from __future__ import unicode_literals
+from __future__ import absolute_import
 
-
-from transaction import Transaction
+from .transaction import Transaction
 
 
 #: conversion table CSB - Homebank for pay modes
@@ -51,4 +52,4 @@ def convertFromCsb(csb):
 
             hbTrans.append(record)
 
-        return hbTrans
\ No newline at end of file
+        return hbTrans
